@@ -176,7 +176,7 @@ class Opower:
         username: str,
         password: str,
         optional_totp_secret: str | None = None,
-        headless_login_service_url: str | None = None,
+        login_data: dict[str, Any] | None = None,
     ) -> None:
         """Initialize."""
         # Note: Do not modify default headers since Home Assistant that uses this library needs to use
@@ -186,7 +186,7 @@ class Opower:
         self.username: str = username
         self.password: str = password
         self.optional_totp_secret: str | None = optional_totp_secret
-        self.headless_login_service_url: str | None = headless_login_service_url
+        self.login_data: dict[str, Any] = login_data or {}
         self.access_token: str | None = None
         self.customers: list[Any] = []
         self.user_accounts: list[Any] = []
@@ -202,11 +202,7 @@ class Opower:
         try:
             if self.utility.accepts_totp_secret() and self.optional_totp_secret:
                 self.utility.set_totp_secret(self.optional_totp_secret.strip())
-            if self.utility.requires_headless_login_service():
-                if not self.headless_login_service_url:
-                    raise ValueError("Headless login service URL is required for this utility but was not provided.")
-                self.utility.set_headless_login_service_url(self.headless_login_service_url.rstrip("/"))
-            self.access_token = await self.utility.async_login(self.session, self.username, self.password)
+            self.access_token = await self.utility.async_login(self.session, self.username, self.password, self.login_data)
 
         except ClientResponseError as err:
             if err.status in (401, 403):
